@@ -2,7 +2,7 @@ package OptArgs;
 use strict;
 use warnings;
 use Carp qw/croak carp/;
-use Encode qw/decode decode_utf8/;
+use Encode qw/decode decode_utf8 encode_utf8/;
 use Exporter::Tidy
   default => [qw/opt arg optargs usage subcmd/],
   other   => [qw/dispatch/];
@@ -319,6 +319,14 @@ sub _optargs {
             @ARGV =
               map { Encode::is_utf8($_) ? $_ : decode( $codeset, $_ ) } @ARGV;
         }
+        else {
+            for ( 0 .. $#ARGV ) {
+                my $utf8 = eval {
+                    decode_utf8( encode_utf8( $ARGV[$_] ), Encode::FB_CROAK );
+                };
+                $ARGV[$_] = $utf8 unless $@;
+            }
+        }
 
         $source = \@ARGV;
     }
@@ -389,7 +397,8 @@ sub _optargs {
     }
 
     if ($ishelp) {
-        die _usage( $package, "[help request]" );
+        print _usage( $package, "[help request]" );
+        exit 2;
     }
     elsif ($missing_required) {
         die _usage($package);
